| exportADMS | R Documentation |
This function is part of an old worldmet API. Please use the following
alternatives:
exportADMS() -> write_adms()
the path argument -> write_met()
exportADMS(dat, out = "./ADMS_met.MET", interp = FALSE, maxgap = 2)
dat |
A data frame imported by |
out |
A file name for the ADMS file. The file is written to the working directory by default. |
interp |
Should interpolation of missing values be undertaken? If |
maxgap |
The maximum gap in hours that should be interpolated where
there are missing data when |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.