View source: R/import_ghcn_stations.R
| import_ghcn_countries | R Documentation |
This function returns a two-column dataframe either of "Federal Information Processing Standards" (FIPS) codes and the countries to which they are associated, or state codes and their associated states. These may be a useful reference when examining GHCN site metadata.
import_ghcn_countries(
table = c("countries", "states"),
database = c("hourly", "daily", "monthly")
)
table |
One of |
database |
One of |
a tibble
Jack Davison
Other GHCN functions:
import_ghcn_daily(),
import_ghcn_hourly(),
import_ghcn_inventory(),
import_ghcn_monthly_temp(),
import_ghcn_stations()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.