View source: R/import_ghcn_stations.R
| import_ghcn_inventory | R Documentation |
This function accesses a data inventory of GHCN stations available through
either the GHCNh or GHCNd. The returned data.frame contains data which
reveals the earliest and latest years of data available for each station from
the NOAA database.
import_ghcn_inventory(
database = c("hourly", "daily"),
pivot = c("wide", "long"),
progress = rlang::is_interactive()
)
database |
One of |
pivot |
One of |
progress |
The inventory file is large and can be slow to download. Show
a progress indicator when accessing the inventory? Defaults to |
a tibble
Jack Davison
Other GHCN functions:
import_ghcn_countries(),
import_ghcn_daily(),
import_ghcn_hourly(),
import_ghcn_monthly_temp(),
import_ghcn_stations()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.