| write_adms | R Documentation |
Writes a text file in the ADMS format to a location of the user's choosing,
with optional interpolation of missing values. This function works with data
from both import_ghcn_hourly() and import_isd_hourly().
write_adms(x, file = "./ADMS_met.MET", interp = FALSE, max_gap = 2)
x |
A data frame imported by |
file |
A file name for the ADMS file. The file is written to the working directory by default. |
interp |
Should interpolation of missing values be undertaken? If |
max_gap |
The maximum gap in hours that should be interpolated where
there are missing data when |
write_adms() returns the input dat invisibly.
Other Met writing functions:
write_met()
## Not run:
# import some data then export it
dat <- import_isd_hourly(year = 2012)
write_adms(dat, file = "~/adms_met.MET")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.