| getMeta | R Documentation |
This function is part of an old worldmet API. Please use the following
alternatives:
getMeta() -> import_isd_stations()
getMetaLive() -> import_isd_stations_live()
importNOAA() -> import_isd_hourly()
importNOAAlite() -> import_isd_lite()
the path argument -> write_met()
getMeta(
site = NULL,
lat = NULL,
lon = NULL,
crs = 4326,
country = NULL,
state = NULL,
n = 10,
end.year = "current",
provider = c("OpenStreetMap", "Esri.WorldImagery"),
plot = TRUE,
returnMap = FALSE
)
getMetaLive(...)
importNOAA(
code = "037720-99999",
year = 2014,
hourly = TRUE,
source = c("delim", "fwf"),
quiet = FALSE,
path = NA,
n.cores = NULL
)
importNOAAlite(code = "037720-99999", year = 2025, quiet = FALSE, path = NA)
site |
A site name search string e.g. |
lat, lon |
Decimal latitude and longitude (or other Y/X coordinate if
using a different |
crs |
The coordinate reference system (CRS) of the data, passed to
|
country |
The country code. This is a two letter code. For a full listing see https://www.ncei.noaa.gov/pub/data/noaa/isd-history.csv. |
state |
The state code. This is a two letter code. |
n |
The number of nearest sites to search based on |
end.year |
To help filter sites based on how recent the available data
are. |
provider |
By default a map will be created in which readers may toggle
between a vector base map and a satellite/aerial image. |
plot |
If |
returnMap |
Should the leaflet map be returned instead of the meta data?
Default is |
... |
Currently unused. |
code |
The identifying code as a character string. The code is a
combination of the USAF and the WBAN unique identifiers. The codes are
separated by a “-” e.g. |
year |
The year to import. This can be a vector of years e.g. |
hourly |
Should hourly means be calculated? The default is |
source |
The NOAA ISD service stores files in two formats; as delimited
CSV files ( |
quiet |
Print missing sites/years to the screen? Defaults to |
path |
If a file path is provided, the data are saved as an rds file at
the chosen location e.g. |
n.cores |
No longer recommended; please set |
A data frame is returned with all available meta data, mostly
importantly including a code that can be supplied to importNOAA(). If
latitude and longitude searches are made an approximate distance, dist in
km is also returned.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.