This function returns a two-column dataframe either of "Federal Information Processing Standards" (FIPS) codes and the countries to which they are associated, or state codes and their associated states. These may be a useful reference when examining GHCN site metadata.
import_ghcn_countries(
table = c("countries", "states"),
database = c("hourly", "daily", "monthly")
)a tibble
One of "countries" or "states".
One of "hourly", "daily" or "monthly", which defines
which of the NOAA databases to import the FIPS codes from. There is little
difference between the data in the different sources, but this option may
be useful if one of the services is not accessible.
Jack Davison
Other GHCN functions:
import_ghcn_daily(),
import_ghcn_hourly(),
import_ghcn_inventory(),
import_ghcn_monthly_temp(),
import_ghcn_stations()