View source: R/import_ghcn_stations.R
| import_ghcn_stations | R Documentation |
This function accesses a full list of GHCN stations available through either
the GHCNh or GHCNd. As well as the station id, needed for importing
measurement data, useful geographic and network metadata is also returned.
import_ghcn_stations(
name = NULL,
country = NULL,
state = NULL,
lat = NULL,
lng = NULL,
crs = 4326,
n_max = 10L,
database = c("hourly", "daily"),
return = c("table", "sf", "map")
)
name, country, state |
String values to use to filter the metadata for
specific site names, countries and states. |
lat, lng, n_max |
Decimal latitude ( |
crs |
The coordinate reference system (CRS) of the data, passed to
|
database |
One of |
return |
The type of R object to import the GHCN stations as. One of the following:
|
One of:
a tibble
an sf object
an interactive leaflet map
Jack Davison
Other GHCN functions:
import_ghcn_countries(),
import_ghcn_daily(),
import_ghcn_hourly(),
import_ghcn_inventory(),
import_ghcn_monthly_temp()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.