Functions to import data from more than 30,000 surface meteorological sites around the world managed by the National Oceanic and Atmospheric Administration (NOAA) Global Historical Climate Network (GHCN) and Integrated Surface Database (ISD).
Maintainer: David Carslaw david.carslaw@york.ac.uk (ORCID)
Authors:
Jack Davison jack.davison@ricardo.com (ORCID)
This package contains functions to import surface meteorological data from over 30,000 sites around the world. These data are curated by NOAA as part of the Global Historical Climate Network (GHCN), which replaced the Integrated Surface Database (ISD) in 2025.
If you access these data using the worldmet package please give full
acknowledgement to NOAA. Users should also take a note of the usage
restrictions.
These data work well with the openair package that has been developed to
analyse air pollution data.
For general information about the GHCNh, see https://www.ncei.noaa.gov/products/global-historical-climatology-network-hourly.
For general information about the legacy ISD service, see https://www.ncei.noaa.gov/products/land-based-station/integrated-surface-database.
See https://github.com/openair-project/openair for information on
the related openair package.