| write_met | R Documentation |
Writes a text file in the ADMS format to a location of the user's choosing,
with optional interpolation of missing values. At present this function only
works with data from import_isd_hourly(); it will later be expanded to work
with import_ghcn_hourly() also.
write_met(
x,
path = ".",
ext = c("rds", "delim", "parquet"),
delim = ",",
suffix = "",
progress = rlang::is_interactive()
)
x |
A data frame imported by |
path |
The path to a directory to save each file. By default, this is the working directory. |
ext |
The file type to use when saving the data. Can be |
delim |
Delimiter used to separate values when |
suffix |
An additional suffix to append to file names. Useful examples
could be |
progress |
Show a progress bar when writing many stations/years?
Defaults to |
write_met() returns path invisibly.
Other Met writing functions:
write_adms()
## Not run:
# import some data then export it
dat <- import_isd_hourly(year = 2012)
write_met(dat)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.